/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
#ifndef _PK11FUNC_H_
#define _PK11FUNC_H_

/*
 * The original pk11func.h had a mix of public and private functions.
 * Continue to provide those for backward compatibility.  New code should
 * include pk11pub.h instead of pk11func.h.
 */
#include "pk11pub.h"
#include "pk11priv.h"

#endif
