/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

[builtinclass, uuid(3fdc07cb-3b2e-4c6e-a054-008a4f302202)]
interface nsIDOMCommandEvent : nsIDOMEvent
{
  readonly attribute DOMString command;

  void initCommandEvent(in DOMString typeArg,
                        in boolean canBubbleArg,
                        in boolean canCancelArg,
                        in DOMString command);
};
