/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
#ifndef nsDateTimeFormatCID_h__
#define nsDateTimeFormatCID_h__


#include "nscore.h"
#include "nsISupports.h"

#define NS_DATETIMEFORMAT_CONTRACTID "@mozilla.org/intl/datetimeformat;1"

// {0704E7C0-A758-11d2-9119-006008A6EDF6}
#define NS_DATETIMEFORMAT_CID \
{ 0x704e7c0, 0xa758, 0x11d2, \
{ 0x91, 0x19, 0x0, 0x60, 0x8, 0xa6, 0xed, 0xf6 } }

#endif  // nsDateTimeFormatCID_h__

