/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMElement.idl"

interface nsIDOMCSSStyleDeclaration;
interface nsIDOMCSSValue;


[uuid(c63517c5-8bab-4cd1-8694-bccafc32a195)]
interface nsIDOMSVGElement : nsIDOMElement
{
            // raises DOMException on setting
  readonly attribute nsIDOMSVGElement    ownerSVGElement;
  readonly attribute nsIDOMSVGElement    viewportElement;

  [binaryname(SVGClassName)]
  readonly attribute nsISupports   className;
  readonly attribute nsIDOMCSSStyleDeclaration style;
};
